import base64
import boto3
import json
import os
from dukeai.config import img_ocr_funtion_arn, pdf_ocr_funtion_arn


def duke_ocr(file_directory):
    """
        This is the ocr funtion which extracts text out of IMAGEs and PDFs

        Requirements:
            Define "AWS_ACCESS_KEY_ID" and "AWS_SECRET_ACCESS_KEY" as environement variable

        Code:
            import os
            os.environ['AWS_ACCESS_KEY_ID'] = "--AWS_ACCESS_KEY_ID--"
            os.environ['AWS_SECRET_ACCESS_KEY'] = "--AWS_SECRET_ACCESS_KEY--"

        Args:
            file_directory (string): file directory you want the ocr from
        Returns:
            return1 (dic): {'text': 'Dummy PDF file\n\x0c'}
    z

    """
    
    if "AWS_ACCESS_KEY_ID" not in os.environ:
        print('AWS_ACCESS_KEY_ID key not found')
        print('Define "AWS_ACCESS_KEY_ID" in environment')
        return None

    if "AWS_SECRET_ACCESS_KEY" not in os.environ:
        print('AWS_SECRET_ACCESS_KEY key not found')
        print('Define "AWS_SECRET_ACCESS_KEY" in environment')
        return None

    lambda_client = boto3.client('lambda', region_name='us-east-1')

    payload = json.dumps({
                           "local": True,
                           "body": base64.b64encode(open(file_directory, 'rb').read()).decode('utf-8'),
                        })

    if file_directory.split('.')[-1].lower() in ['pdf']:
        lambda_response = lambda_client.invoke(
                                                FunctionName=pdf_ocr_funtion_arn,
                                                InvocationType='RequestResponse',
                                                Payload=payload
                                              )
        resp_str = lambda_response['Payload'].read()
        response = json.loads(resp_str)
        return response

    if file_directory.split('.')[-1].lower() in ['jpeg', 'jpg', 'png']:
        lambda_response = lambda_client.invoke(
                                                FunctionName=img_ocr_funtion_arn,
                                                InvocationType='RequestResponse',
                                                Payload=payload
                                              )

        resp_str = lambda_response['Payload'].read()
        response = json.loads(resp_str)
        return response



import requests
from dukeai.config import base_url


def get_token(username, password):
    url = "https://api.duke.ai/token/get_token"

    headers = {
              'username': username.upper(),
              'password': password
             }

    response = requests.request("GET", url, headers=headers)

    return response.json


def get_tax_info(cust_id, token, tax_info):
    url = base_url + f'/{cust_id}/tax_info/{tax_info}'

    headers = {
                'Authorization': token
              }
    response = requests.request("GET", url, headers=headers)

    return response.text


def update_tax_info(cust_id, token, tax_info, payload):
    """
            payload =   {
                          "Filling_Status": "string",
                          "Pre_tax_deduction": {
                            "status": true,
                            "amount": 0
                          },
                          "Tax_credit": {
                            "status": true,
                            "amount": 0
                          },
                          "Standard_Deduction": {
                            "status": true
                          },
                          "Itemize_Deduction": {
                            "status": true,
                            "amount": 0
                          },
                          "Other_Income": 0
                        }
    """

    url = base_url + f'/{cust_id}/tax_info/{tax_info}'

    headers = {
               'Authorization': token,
               'Content-Type': 'application/json'
              }

    response = requests.request("POST", url, headers=headers, data=payload)

    return response.text


def get_ifta_trip_id(cust_id, token):

    url = base_url + f'/{cust_id}/ifta'

    headers = {
                'Authorization': token
              }

    response = requests.request("GET", url, headers=headers)

    return response.text


def send_ifta_data(cust_id, token):
    """
    payload = {
                  "positionList": [
                    {
                      "timestamp": "string",
                      "state": "string",
                      "longitude": "string",
                      "latitude": "string"
                    }
                  ],
                  "tripId": "c9c3cf65-e8fd-42b1-b600-a09bf2bf8838",
                  "status": "new"
                }
    """
    url = base_url + f'/{cust_id}/ifta'

    headers = {
                'Authorization': token,
                'Content-Type': 'application/json'
              }

    response = requests.request("POST", url, headers=headers)

    return response.text
